@@ -12,9 +12,6 @@ import plistlib
 import socket
 
 
-#   TODO: List of clients that are actually reachable by network, but do not have xsanio_client installed
-
-
 LOGGER = logging.getLogger(__name__)
 LOG_FORMAT = ('%(levelname) -10s %(asctime)s %(name) -30s %(funcName) '
               '-35s %(lineno) -5d: %(message)s')
@@ -85,6 +82,18 @@ def update_volume_list(xsan_config_path, xsan_config_regex, config_node_regex):
         LOGGER.warning('We don\'t seem to be running on an MDC!')
 
 
+def client_is_unreachable(client):
+    """Ping the client.
+    True == client is reachable
+    False == client is not
+
+    """
+    host_name = client.host_name
+    ping_response = os.system("ping -c 1 %s" % host_name)
+
+    return ping_response
+
+
 def parse_client_io_data(client, io_data):
     """Gotta be careful here, since there should be only one stat entry for each status entry type for each host
 
@@ -181,27 +190,31 @@ def get_stats_from_client(client):
     io_data = None
     http_response = None
 
-    try:
-        LOGGER.info('Requesting stats from %s', client.host_name)
-        http_conn = httplib.HTTPConnection(host=client.ip_address, port=client.port, timeout=3)
-        http_conn.request('GET', '/')
-        http_response = http_conn.getresponse()
-    except:
-        LOGGER.warning('Client %s in unreachable', client.host_name)
+    if not client_is_unreachable(client):
+        try:
+            LOGGER.info('Requesting stats from %s', client.host_name)
+            http_conn = httplib.HTTPConnection(host=client.ip_address, port=client.port, timeout=3)
+            http_conn.request('GET', '/')
+            http_response = http_conn.getresponse()
+        except:
+            LOGGER.warning('Client %s does not have xsanio_client installed', client.host_name)
+            client.has_client_installed = False
+            client.save()
+            return
+
+
+        if http_response.status == 200:
+            client.has_client_installed = True
+            client.save()
+            host_response_data = http_response.read()
+            io_data = json.loads(host_response_data)
+            parse_client_io_data(client, io_data)
+            LOGGER.info('Finished parsing response from %s', client.host_name)
+        else:
+            LOGGER.error("Client %s responded with %s", client.host_name, http_response.status)
+    else:
         client.is_unreachable = True
         client.save()
-        return
-
-
-    if http_response.status == 200:
-        client.is_unreachable = False
-        client.save()
-        host_response_data = http_response.read()
-        io_data = json.loads(host_response_data)
-        parse_client_io_data(client, io_data)
-        LOGGER.info('Finished parsing response from %s', client.host_name)
-    else:
-        LOGGER.error("Client %s responded with %s", client.host_name, http_response.status)
 
 
 def discover_clients(xsan_config_dir):
